Learn R Programming

bidux (version 0.3.3)

bid_set_quiet: Set global quiet mode for bidux functions

Description

Convenience function to set the global quiet option for all bidux functions. When quiet mode is enabled, most informational messages are suppressed.

Usage

bid_set_quiet(quiet = TRUE)

Value

The previous value of the quiet option (invisibly)

Arguments

quiet

Logical indicating whether to enable quiet mode. When TRUE, most bidux messages are suppressed.

Examples

Run this code
# Enable quiet mode
bid_set_quiet(TRUE)

# Disable quiet mode
bid_set_quiet(FALSE)

Run the code above in your browser using DataLab