Learn R Programming

bidux (version 0.3.3)

bidux-package: bidux: Behavioral Insight Design: A Toolkit for Integrating Behavioral Science in UI/UX Design

Description

logo

Provides a framework and toolkit to guide R dashboard developers in implementing the Behavioral Insight Design (BID) framework. The package offers functions for documenting each of the five stages (Interpret, Notice, Anticipate, Structure, and Validate), along with a comprehensive concept dictionary. Works with both 'shiny' applications and 'Quarto' dashboards.

Arguments

Author

Maintainer: Jeremy Winget contact@jrwinget.com (ORCID)

See Also