extract_span_attribute: Extract an attribute value from span attributes by key names

View source: R/telemetry_otel_conversion.R

extract_span_attributeR Documentation

Extract an attribute value from span attributes by key names

Description

Extract an attribute value from span attributes by key names

Usage

extract_span_attribute(span_attributes, key_names)

Arguments

span_attributes

The attributes object (data.frame, named list, or list-of-objects)

key_names

Character vector of possible key names to look for

Value

The extracted value as character, or NA_character_ if not found


bidux documentation built on Feb. 28, 2026, 1:06 a.m.