load_theory_mappings: Load theory mappings from external file or use defaults

View source: R/mappings.R

load_theory_mappingsR Documentation

Load theory mappings from external file or use defaults

Description

Load theory mappings from external file or use defaults

Usage

load_theory_mappings(custom_mappings = NULL)

Arguments

custom_mappings

Optional custom mappings data frame

Value

Data frame with theory mappings


bidux documentation built on Feb. 28, 2026, 1:06 a.m.