Learn R Programming

bidux (version 0.3.3)

suggest_theory_from_mappings: Suggest theory based on problem and evidence using mappings

Description

Suggest theory based on problem and evidence using mappings

Usage

suggest_theory_from_mappings(problem, evidence = NULL, mappings = NULL)

Value

Character string with suggested theory

Arguments

problem

Character string describing the problem

evidence

Optional character string with supporting evidence

mappings

Optional custom theory mappings