powered by
Convenience function to set the global quiet option for all bidux functions. When quiet mode is enabled, most informational messages are suppressed.
bid_set_quiet(quiet = TRUE)
The previous value of the quiet option (invisibly)
Logical indicating whether to enable quiet mode. When TRUE, most bidux messages are suppressed.
# Enable quiet mode bid_set_quiet(TRUE) # Disable quiet mode bid_set_quiet(FALSE)
Run the code above in your browser using DataLab