View source: R/telemetry_otel_conversion.R
| extract_span_attribute | R Documentation |
Extract an attribute value from span attributes by key names
extract_span_attribute(span_attributes, key_names)
span_attributes |
The attributes object (data.frame, named list, or list-of-objects) |
key_names |
Character vector of possible key names to look for |
The extracted value as character, or NA_character_ if not found
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.