Learn R Programming

bidux (version 0.4.0)

extract_span_attribute: Extract an attribute value from span attributes by key names

Description

Extract an attribute value from span attributes by key names

Usage

extract_span_attribute(span_attributes, key_names)

Value

The extracted value as character, or NA_character_ if not found

Arguments

span_attributes

The attributes object (data.frame, named list, or list-of-objects)

key_names

Character vector of possible key names to look for