| get_concept_keywords | R Documentation |
Returns the single authoritative mapping of behavioral science concept names
to keyword vectors. This is the merged union of all keyword sets previously
scattered across infer_concepts_from_story() and
detect_concepts_from_text().
get_concept_keywords()
Named list mapping concept names to keyword vectors
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.