load_theory_mappings: Load theory mappings from external file or use defaults
Description
Load theory mappings from external file or use defaults
Usage
load_theory_mappings(custom_mappings = NULL)
Value
Data frame with theory mappings
Arguments
- custom_mappings
Optional custom mappings data frame